# AutoRA Terminology

The following table includes naming conventions used throughout AutoRA.

| Term                 | Description                                                                                                                                                                                                                     | Relevant Modules                                |
|----------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------|
| State                | Object representing data from an experiment, like the conditions, observed experiment data and models. The State also includes rules on how to update those data if new data are provided using the "Delta mechanism".          | Core                                            |
| Delta                | An object with new data that can be added to a State, returning a new State which includes the new data.                                                                                                                        | Core                                            |
| StandardState        | An optional default State that has the following fields: ``variables``, ``conditions``, ``experiment_data``, ``models``.                                                                                                        | Core                                            |
| Variables            | A State field (``state.variables``) that holds experimental variables, which are defined according to name, type, units, allowed values, and range.                                                                             | Experimentalists, Experiment Runners, Theorists |
| Independent Variable | An experimental variable that the researcher intends to manipulate or change to observe its effect. A parameteriation of independent variables is called a *condition*.                                                         | Experimentalists, Experiment Runners, Theorists |
| Dependent Variable   | An experimental variable that that is measured or observed in response to changes in the independent variable. Values of independent variables are referred to as *observations* and are part of the *experimental data*. | Experimentalists, Experiment Runners, Theorists |
| VariableCollection   | Immutable metadata about dependent variables, independent variables, and covariates.                                                                                                                                            | Experimentalists, Experiment Runners, Theorists |
| Conditions           | A State field (``state.conditions``) that defines what observations should be collected according to a specific combination of values of the independent variables                                                              | Experimentalists, Experiment Runners, Theorists |
| Experiment Data      | A State field (``state.experiment_data``) that holds specified conditions as well as the corresponding observations.                                                                                                            | Experiment Runners, Theorists                   |
| Model                | A State field (``state.models``) that holds the the collection of best fit models produced by theorists.                                                                                                                        | Theorists, Experimentalists                     |
| Components           | The functions that can act on the State (e.g., experimentalists, experiment runners, theorists).                                                                                                                                | Experimentalists, Experiment Runners, Theorists |
| Experimentalist      | A component that outputs new conditions, which are intended to yield novel observations.                                                                                                                                        | Experimentalists                                |
| Theorist             | A component that takes in the full collection of conditions and observations and outputs models that link the two.                                                                                                              | Theorists                                       |
| Experiment Runner    | A component that takes in conditions and collects corresponding observations.                                                                                                                                                   | Experiment Runners                              |
| Wrapper              | Special functions that make the components of AutoRA able to operate on State objects.                                                                                                                                          | Experimentalists, Experiment Runners, Theorists |
| Workflow             | A collection of tools that enable closed-loop empirical research with the AutoRA framework.                                                                                                                                     | Experimentalists, Experiment Runners, Theorists |
